@@ -1,5 +1,7 @@
 import logging
+import numpy as np
 from os import devnull
+from math import ceil
 from psutil import cpu_count
 from contextlib import contextmanager, redirect_stderr, redirect_stdout
 
@@ -37,6 +39,8 @@ class _SwifterBaseObject:
     def __init__(self, base_obj, npartitions=None):
         self._obj = base_obj
         self._nrows = self._obj.shape[0]
+        self._SAMPLE_SIZE = SAMPLE_SIZE if self._nrows > (25 * SAMPLE_SIZE) else int(ceil(self._nrows / 25))
+        self._SAMPLE_INDEX = sorted(np.random.choice(range(self._nrows), size=self._SAMPLE_SIZE, replace=False))
         self._ray_memory = None
         self.set_npartitions(npartitions=npartitions)
 
