@@ -4,7 +4,6 @@ import numpy as np
 import pandas as pd
 
 from abc import abstractmethod
-from math import ceil
 from dask import dataframe as dd
 
 from tqdm.auto import tqdm
@@ -14,21 +13,67 @@ from .base import (
     _SwifterBaseObject,
     suppress_stdout_stderr_logging,
     ERRORS_TO_HANDLE,
-    SAMPLE_SIZE,
     N_REPEATS,
 )
 
+DEFAULT_KWARGS = {
+    "npartitions": None,
+    "dask_threshold": 1,
+    "scheduler": "processes",
+    "progress_bar": True,
+    "progress_bar_desc": None,
+    "allow_dask_on_strings": False,
+}
 
-class _SwifterObject(_SwifterBaseObject):
-    def __init__(
-        self,
-        pandas_obj,
+
+def register_default_config_dataframe_accessor(dataframe_to_register, kwargs):
+    """
+    Register dataframe type with default swifter config
+    """
+    current_init = dataframe_to_register.__init__
+
+    def new_init(self, *args, **kwds):
+        current_init(self, *args, **kwds)
+        self.swifter = (
+            self.swifter.set_npartitions(npartitions=kwargs.get("npartitions", DEFAULT_KWARGS["npartitions"]))
+            .set_dask_threshold(dask_threshold=kwargs.get("dask_threshold", DEFAULT_KWARGS["dask_threshold"]))
+            .set_dask_scheduler(scheduler=kwargs.get("scheduler", DEFAULT_KWARGS["scheduler"]))
+            .progress_bar(
+                enable=kwargs.get("progress_bar", DEFAULT_KWARGS["progress_bar"]),
+                desc=kwargs.get("progress_bar_desc", DEFAULT_KWARGS["progress_bar_desc"]),
+            )
+            .allow_dask_on_strings(enable=kwargs.get("allow_dask_on_strings", DEFAULT_KWARGS["allow_dask_on_strings"]))
+        )
+
+    dataframe_to_register.__init__ = new_init
+
+
+def set_defaults(**kwargs):
+    """
+    Register swifter's default kwargs
         npartitions=None,
         dask_threshold=1,
         scheduler="processes",
         progress_bar=True,
         progress_bar_desc=None,
         allow_dask_on_strings=False,
+    """
+    from pandas import Series, DataFrame
+
+    register_default_config_dataframe_accessor(Series, kwargs)
+    register_default_config_dataframe_accessor(DataFrame, kwargs)
+
+
+class _SwifterObject(_SwifterBaseObject):
+    def __init__(
+        self,
+        pandas_obj,
+        npartitions=DEFAULT_KWARGS["npartitions"],
+        dask_threshold=DEFAULT_KWARGS["dask_threshold"],
+        scheduler=DEFAULT_KWARGS["scheduler"],
+        progress_bar=DEFAULT_KWARGS["progress_bar"],
+        progress_bar_desc=DEFAULT_KWARGS["progress_bar_desc"],
+        allow_dask_on_strings=DEFAULT_KWARGS["allow_dask_on_strings"],
     ):
         super().__init__(base_obj=pandas_obj, npartitions=npartitions)
         if self._obj.index.duplicated().any():
@@ -37,11 +82,6 @@ class _SwifterObject(_SwifterBaseObject):
                 "and swifter may not be able to improve performance. "
                 "Consider resetting the indices with `df.reset_index(drop=True)`."
             )
-        self._SAMPLE_SIZE = (
-            SAMPLE_SIZE
-            if self._nrows > (25 * SAMPLE_SIZE)
-            else int(ceil(self._nrows / 25))
-        )
         self._dask_threshold = dask_threshold
         self._scheduler = scheduler
         self._progress_bar = progress_bar
@@ -165,14 +205,12 @@ class SeriesAccessor(_SwifterObject):
     def _wrapped_apply(self, func, convert_dtype=True, args=(), **kwds):
         def wrapped():
             with suppress_stdout_stderr_logging():
-                self._obj.iloc[: self._SAMPLE_SIZE].apply(
-                    func, convert_dtype=convert_dtype, args=args, **kwds
-                )
+                self._obj.iloc[self._SAMPLE_INDEX].apply(func, convert_dtype=convert_dtype, args=args, **kwds)
 
         return wrapped
 
     def _dask_apply(self, func, convert_dtype, *args, **kwds):
-        sample = self._obj.iloc[: self._npartitions * 2]
+        sample = self._obj.iloc[self._SAMPLE_INDEX]
         with suppress_stdout_stderr_logging():
             meta = sample.apply(func, convert_dtype=convert_dtype, args=args, **kwds)
         try:
@@ -185,9 +223,7 @@ class SeriesAccessor(_SwifterObject):
                 )
                 self._validate_apply(
                     tmp_df.equals(meta),
-                    error_message=(
-                        "Dask map-partitions sample does not match pandas apply sample."
-                    ),
+                    error_message=("Dask map-partitions sample does not match pandas apply sample."),
                 )
             if self._progress_bar:
                 with TQDMDaskProgressBar(desc=self._progress_bar_desc or "Dask Apply"):
@@ -236,12 +272,10 @@ class SeriesAccessor(_SwifterObject):
         if not self._nrows:
             return self._obj.apply(func, convert_dtype=convert_dtype, args=args, **kwds)
 
-        sample = self._obj.iloc[: self._npartitions * 2]
+        sample = self._obj.iloc[self._SAMPLE_INDEX]
         # check if input is string or
         # if the user is overriding the string processing default
-        allow_dask_processing = (
-            True if self._allow_dask_on_strings else (sample.dtype != "object")
-        )
+        allow_dask_processing = True if self._allow_dask_on_strings else (sample.dtype != "object")
 
         if "axis" in kwds.keys():
             kwds.pop("axis")
@@ -250,26 +284,17 @@ class SeriesAccessor(_SwifterObject):
         try:  # try to vectorize
             with suppress_stdout_stderr_logging():
                 tmp_df = func(sample, *args, **kwds)
-                sample_df = sample.apply(
-                    func, convert_dtype=convert_dtype, args=args, **kwds
-                )
+                sample_df = sample.apply(func, convert_dtype=convert_dtype, args=args, **kwds)
                 self._validate_apply(
-                    np.array_equal(sample_df, tmp_df)
-                    & (sample_df.shape == tmp_df.shape),
-                    error_message=(
-                        "Vectorized function sample doesn't match pandas apply sample."
-                    ),
+                    np.array_equal(sample_df, tmp_df) & (hasattr(tmp_df, "shape")) & (sample_df.shape == tmp_df.shape),
+                    error_message=("Vectorized function sample doesn't match pandas apply sample."),
                 )
             return func(self._obj, *args, **kwds)
         except ERRORS_TO_HANDLE:  # if can't vectorize, estimate time to pandas apply
-            wrapped = self._wrapped_apply(
-                func, convert_dtype=convert_dtype, args=args, **kwds
-            )
+            wrapped = self._wrapped_apply(func, convert_dtype=convert_dtype, args=args, **kwds)
             timed = timeit.timeit(wrapped, number=N_REPEATS)
             sample_proc_est = timed / N_REPEATS
-            est_apply_duration = (
-                sample_proc_est / self._SAMPLE_SIZE * self._obj.shape[0]
-            )
+            est_apply_duration = sample_proc_est / self._SAMPLE_SIZE * self._nrows
 
             # if pandas sample apply takes too long and not performing str processing
             # then use dask
@@ -278,13 +303,9 @@ class SeriesAccessor(_SwifterObject):
             else:  # use pandas
                 if self._progress_bar:
                     tqdm.pandas(desc=self._progress_bar_desc or "Pandas Apply")
-                    return self._obj.progress_apply(
-                        func, convert_dtype=convert_dtype, args=args, **kwds
-                    )
+                    return self._obj.progress_apply(func, convert_dtype=convert_dtype, args=args, **kwds)
                 else:
-                    return self._obj.apply(
-                        func, convert_dtype=convert_dtype, args=args, **kwds
-                    )
+                    return self._obj.apply(func, convert_dtype=convert_dtype, args=args, **kwds)
 
 
 @pd.api.extensions.register_dataframe_accessor("swifter")
@@ -292,18 +313,16 @@ class DataFrameAccessor(_SwifterObject):
     def _wrapped_apply(self, func, axis=0, raw=None, result_type=None, args=(), **kwds):
         def wrapped():
             with suppress_stdout_stderr_logging():
-                self._obj.iloc[: self._SAMPLE_SIZE, :].apply(
+                self._obj.iloc[self._SAMPLE_INDEX].apply(
                     func, axis=axis, raw=raw, result_type=result_type, args=args, **kwds
                 )
 
         return wrapped
 
     def _dask_apply(self, func, axis=0, raw=None, result_type=None, *args, **kwds):
-        sample = self._obj.iloc[: self._npartitions * 2, :]
+        sample = self._obj.iloc[self._SAMPLE_INDEX]
         with suppress_stdout_stderr_logging():
-            meta = sample.apply(
-                func, axis=axis, raw=raw, result_type=result_type, args=args, **kwds
-            )
+            meta = sample.apply(func, axis=axis, raw=raw, result_type=result_type, args=args, **kwds)
         try:
             with suppress_stdout_stderr_logging():
                 # check that the dask apply matches the pandas apply
@@ -361,9 +380,7 @@ class DataFrameAccessor(_SwifterObject):
             else:
                 apply_func = self._obj.apply
 
-            return apply_func(
-                func, axis=axis, raw=raw, result_type=result_type, args=args, **kwds
-            )
+            return apply_func(func, axis=axis, raw=raw, result_type=result_type, args=args, **kwds)
 
     def apply(self, func, axis=0, raw=False, result_type=None, args=(), **kwds):
         """
@@ -371,50 +388,31 @@ class DataFrameAccessor(_SwifterObject):
         """
         # If there are no rows return early using Pandas
         if not self._nrows:
-            return self._obj.apply(
-                func, axis=axis, raw=raw, result_type=result_type, args=args, **kwds
-            )
+            return self._obj.apply(func, axis=axis, raw=raw, result_type=result_type, args=args, **kwds)
 
-        sample = self._obj.iloc[: self._npartitions * 2, :]
+        sample = self._obj.iloc[self._SAMPLE_INDEX]
         # check if input is string
         # or if the user is overriding the string processing default
-        allow_dask_processing = (
-            True
-            if self._allow_dask_on_strings
-            else ("object" not in sample.dtypes.values)
-        )
+        allow_dask_processing = True if self._allow_dask_on_strings else ("object" not in sample.dtypes.values)
 
         try:  # try to vectorize
             with suppress_stdout_stderr_logging():
                 tmp_df = func(sample, *args, **kwds)
-                sample_df = sample.apply(
-                    func, axis=axis, raw=raw, result_type=result_type, args=args, **kwds
-                )
+                sample_df = sample.apply(func, axis=axis, raw=raw, result_type=result_type, args=args, **kwds)
                 self._validate_apply(
-                    np.array_equal(sample_df, tmp_df)
-                    & (sample_df.shape == tmp_df.shape),
-                    error_message=(
-                        "Vectorized function sample does not match pandas apply sample."
-                    ),
+                    np.array_equal(sample_df, tmp_df) & (hasattr(tmp_df, "shape")) & (sample_df.shape == tmp_df.shape),
+                    error_message=("Vectorized function sample does not match pandas apply sample."),
                 )
             return func(self._obj, *args, **kwds)
         except ERRORS_TO_HANDLE:  # if can't vectorize, estimate time to pandas apply
-            wrapped = self._wrapped_apply(
-                func, axis=axis, raw=raw, result_type=result_type, args=args, **kwds
-            )
+            wrapped = self._wrapped_apply(func, axis=axis, raw=raw, result_type=result_type, args=args, **kwds)
             timed = timeit.timeit(wrapped, number=N_REPEATS)
             sample_proc_est = timed / N_REPEATS
-            est_apply_duration = (
-                sample_proc_est / self._SAMPLE_SIZE * self._obj.shape[0]
-            )
+            est_apply_duration = sample_proc_est / self._SAMPLE_SIZE * self._nrows
 
             # if pandas sample apply takes too long
             # and not performing str processing, use dask
-            if (
-                (est_apply_duration > self._dask_threshold)
-                and allow_dask_processing
-                and axis == 1
-            ):
+            if (est_apply_duration > self._dask_threshold) and allow_dask_processing and axis == 1:
                 return self._dask_apply(func, axis, raw, result_type, *args, **kwds)
             else:  # use pandas
                 if self._progress_bar:
@@ -423,19 +421,17 @@ class DataFrameAccessor(_SwifterObject):
                 else:
                     apply_func = self._obj.apply
 
-                return apply_func(
-                    func, axis=axis, raw=raw, result_type=result_type, args=args, **kwds
-                )
+                return apply_func(func, axis=axis, raw=raw, result_type=result_type, args=args, **kwds)
 
     def _wrapped_applymap(self, func):
         def wrapped():
             with suppress_stdout_stderr_logging():
-                self._obj.iloc[: self._SAMPLE_SIZE, :].applymap(func)
+                self._obj.iloc[self._SAMPLE_INDEX].applymap(func)
 
         return wrapped
 
     def _dask_applymap(self, func):
-        sample = self._obj.iloc[: self._npartitions * 2, :]
+        sample = self._obj.iloc[self._SAMPLE_INDEX]
         with suppress_stdout_stderr_logging():
             meta = sample.applymap(func)
         try:
@@ -448,14 +444,10 @@ class DataFrameAccessor(_SwifterObject):
                 )
                 self._validate_apply(
                     tmp_df.equals(meta),
-                    error_message=(
-                        "Dask applymap sample does not match pandas applymap sample."
-                    ),
+                    error_message=("Dask applymap sample does not match pandas applymap sample."),
                 )
             if self._progress_bar:
-                with TQDMDaskProgressBar(
-                    desc=self._progress_bar_desc or "Dask Applymap"
-                ):
+                with TQDMDaskProgressBar(desc=self._progress_bar_desc or "Dask Applymap"):
                     return (
                         dd.from_pandas(self._obj, npartitions=self._npartitions)
                         .applymap(func, meta=meta)
@@ -486,34 +478,25 @@ class DataFrameAccessor(_SwifterObject):
         if not self._nrows:
             return self._obj.applymap(func)
 
-        sample = self._obj.iloc[: self._npartitions * 2, :]
+        sample = self._obj.iloc[self._SAMPLE_INDEX]
         # check if input is string
         # or if the user is overriding the string processing default
-        allow_dask_processing = (
-            True
-            if self._allow_dask_on_strings
-            else ("object" not in sample.dtypes.values)
-        )
+        allow_dask_processing = True if self._allow_dask_on_strings else ("object" not in sample.dtypes.values)
 
         try:  # try to vectorize
             with suppress_stdout_stderr_logging():
                 tmp_df = func(sample)
                 sample_df = sample.applymap(func)
                 self._validate_apply(
-                    np.array_equal(sample_df, tmp_df)
-                    & (sample_df.shape == tmp_df.shape),
-                    error_message=(
-                        "Vectorized function sample does not match pandas apply sample."
-                    ),
+                    np.array_equal(sample_df, tmp_df) & (sample_df.shape == tmp_df.shape),
+                    error_message=("Vectorized function sample does not match pandas apply sample."),
                 )
             return func(self._obj)
         except ERRORS_TO_HANDLE:  # if can't vectorize, estimate time to pandas apply
             wrapped = self._wrapped_applymap(func)
             timed = timeit.timeit(wrapped, number=N_REPEATS)
             sample_proc_est = timed / N_REPEATS
-            est_apply_duration = (
-                sample_proc_est / self._SAMPLE_SIZE * self._obj.shape[0]
-            )
+            est_apply_duration = sample_proc_est / self._SAMPLE_SIZE * self._nrows
 
             # if pandas sample apply takes too long
             # and not performing str processing, use dask
@@ -613,12 +596,10 @@ class Rolling(Transformation):
             allow_dask_on_strings=allow_dask_on_strings,
         )
         self._rolling_kwds = kwds.copy()
-        self._comparison_pd = self._obj_pd.iloc[: self._npartitions * 2]
+        self._comparison_pd = self._obj_pd.iloc[: self._SAMPLE_SIZE]
         self._sample_pd = self._sample_pd.rolling(**kwds)
         self._obj_pd = self._obj_pd.rolling(**kwds)
-        self._obj_dd = self._obj_dd.rolling(
-            **{k: v for k, v in kwds.items() if k not in ["on", "closed"]}
-        )
+        self._obj_dd = self._obj_dd.rolling(**{k: v for k, v in kwds.items() if k not in ["on", "closed"]})
 
     def _dask_apply(self, func, *args, **kwds):
         try:
@@ -626,36 +607,19 @@ class Rolling(Transformation):
             with suppress_stdout_stderr_logging():
                 tmp_df = (
                     dd.from_pandas(self._comparison_pd, npartitions=self._npartitions)
-                    .rolling(
-                        **{
-                            k: v
-                            for k, v in self._rolling_kwds.items()
-                            if k not in ["on", "closed"]
-                        }
-                    )
+                    .rolling(**{k: v for k, v in self._rolling_kwds.items() if k not in ["on", "closed"]})
                     .apply(func, *args, **kwds)
                     .compute(scheduler=self._scheduler)
                 )
                 self._validate_apply(
-                    tmp_df.equals(
-                        self._comparison_pd.rolling(**self._rolling_kwds).apply(
-                            func, *args, **kwds
-                        )
-                    ),
-                    error_message=(
-                        "Dask rolling apply sample does not match "
-                        "pandas rolling apply sample."
-                    ),
+                    tmp_df.equals(self._comparison_pd.rolling(**self._rolling_kwds).apply(func, *args, **kwds)),
+                    error_message=("Dask rolling apply sample does not match " "pandas rolling apply sample."),
                 )
             if self._progress_bar:
                 with TQDMDaskProgressBar(desc=self._progress_bar_desc or "Dask Apply"):
-                    return self._obj_dd.apply(func, *args, **kwds).compute(
-                        scheduler=self._scheduler
-                    )
+                    return self._obj_dd.apply(func, *args, **kwds).compute(scheduler=self._scheduler)
             else:
-                return self._obj_dd.apply(func, *args, **kwds).compute(
-                    scheduler=self._scheduler
-                )
+                return self._obj_dd.apply(func, *args, **kwds).compute(scheduler=self._scheduler)
         except ERRORS_TO_HANDLE:
             if self._progress_bar:
                 tqdm.pandas(desc=self._progress_bar_desc or "Pandas Apply")
@@ -686,16 +650,14 @@ class Resampler(Transformation):
             allow_dask_on_strings=allow_dask_on_strings,
         )
         self._resampler_kwds = kwds.copy()
-        self._comparison_pd = self._obj_pd.iloc[: self._npartitions * 2]
+        self._comparison_pd = self._obj_pd.iloc[: self._SAMPLE_SIZE]
         self._sample_pd = self._sample_pd.resample(**kwds)
         self._obj_pd = self._obj_pd.resample(**kwds)
         # Setting dask dataframe `self._obj_dd` to None when there are 0 `self._nrows`
         # because swifter will immediately return the pandas form during the apply
         # function if there are 0 `self._nrows`
         self._obj_dd = (
-            self._obj_dd.resample(
-                **{k: v for k, v in kwds.items() if k in ["rule", "closed", "label"]}
-            )
+            self._obj_dd.resample(**{k: v for k, v in kwds.items() if k in ["rule", "closed", "label"]})
             if self._nrows
             else None
         )
@@ -706,37 +668,20 @@ class Resampler(Transformation):
             with suppress_stdout_stderr_logging():
                 tmp_df = (
                     dd.from_pandas(self._comparison_pd, npartitions=self._npartitions)
-                    .resample(
-                        **{
-                            k: v
-                            for k, v in self._resampler_kwds.items()
-                            if k in ["rule", "closed", "label"]
-                        }
-                    )
+                    .resample(**{k: v for k, v in self._resampler_kwds.items() if k in ["rule", "closed", "label"]})
                     .agg(func, *args, **kwds)
                     .compute(scheduler=self._scheduler)
                 )
                 self._validate_apply(
-                    tmp_df.equals(
-                        self._comparison_pd.resample(**self._resampler_kwds).apply(
-                            func, *args, **kwds
-                        )
-                    ),
-                    error_message=(
-                        "Dask resampler apply sample does not match "
-                        "pandas resampler apply sample."
-                    ),
+                    tmp_df.equals(self._comparison_pd.resample(**self._resampler_kwds).apply(func, *args, **kwds)),
+                    error_message=("Dask resampler apply sample does not match " "pandas resampler apply sample."),
                 )
 
             if self._progress_bar:
                 with TQDMDaskProgressBar(desc=self._progress_bar_desc or "Dask Apply"):
-                    return self._obj_dd.agg(func, *args, **kwds).compute(
-                        scheduler=self._scheduler
-                    )
+                    return self._obj_dd.agg(func, *args, **kwds).compute(scheduler=self._scheduler)
             else:
-                return self._obj_dd.agg(func, *args, **kwds).compute(
-                    scheduler=self._scheduler
-                )
+                return self._obj_dd.agg(func, *args, **kwds).compute(scheduler=self._scheduler)
         except ERRORS_TO_HANDLE:
             # use pandas -- no progress_apply available for resampler objects
             return self._obj_pd.apply(func, *args, **kwds)
